/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.renderer.xhtml.image;

import java.util.Map;

import javax.inject.Named;

import org.xwiki.component.annotation.Component;
import org.xwiki.component.annotation.InstantiationStrategy;
import org.xwiki.component.descriptor.ComponentInstantiationStrategy;
import org.xwiki.rendering.listener.reference.ResourceReference;

/**
 * Handle XHTML rendering for images represented as a <a href="http://tools.ietf.org/html/rfc2397">Data URI</a>.
 *
 * @version $Id: 77b8ce1d2315e34fc23781b55c641c81065dff7f $
 * @since 5.4RC1
 */
@Component
@Named("data")
@InstantiationStrategy(ComponentInstantiationStrategy.PER_LOOKUP)
public class DataURIXHTMLImageTypeRenderer extends AbstractXHTMLImageTypeRenderer
{
    @Override
    protected String getImageSrcAttributeValue(ResourceReference reference, Map<String, String> parameters)
    {
        return String.format("%s:%s", reference.getType().getScheme(), reference.getReference());
    }
}
