/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.transformation.linkchecker;

import java.util.List;
import java.util.regex.Pattern;

import org.xwiki.component.annotation.Role;

/**
 * Configuration options for the Link Checker Transformation.
 *
 * @version $Id: b944b3d4668afe1fc291d6121bc9f245e2f58e10 $
 * @since 3.3M2
 */
@Role
public interface LinkCheckerTransformationConfiguration
{
    /**
     * @return the amount of time (in ms) after which a link should be rechecked for validity
     */
    long getCheckTimeout();

    /**
     * @param checkTimeout the time after which a link should be checked again for validity
     */
    void setCheckTimeout(long checkTimeout);

    /**
     * @return the list of document references regexes for which we don't check links (this is used for example to
     *         ensure that the page listing all link statuses is itself excluded ;))
     */
    List<Pattern> getExcludedReferencePatterns();
}
