/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.transformation.macro;

import java.io.PrintWriter;
import java.util.List;
import java.util.Set;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.block.Block;
import org.xwiki.rendering.macro.AbstractNoParameterMacro;
import org.xwiki.rendering.macro.MacroExecutionException;
import org.xwiki.rendering.transformation.MacroTransformationContext;

/**
 * Macro stub for testing a macro that throws an exception when executed.
 *
 * @version $Id: 94ebac817149cabfe7186e3adca6f954be920913 $
 * @since 1.7M3
 */
@Component
@Named("testfailingmacro")
@Singleton
public class TestFailingMacro extends AbstractNoParameterMacro
{
    public class MockMacroExecutionException extends MacroExecutionException
    {
        public MockMacroExecutionException(String message)
        {
            super(message);
        }

        @Override
        public void printStackTrace(PrintWriter writer)
        {
            writer.print("stack trace here");
        }
    }

    public TestFailingMacro()
    {
        super("Failing Macro");
        setDefaultCategories(Set.of("Test"));
    }

    @Override
    public boolean supportsInlineMode()
    {
        return true;
    }

    @Override
    public List<Block> execute(Object parameters, String content, MacroTransformationContext context)
        throws MacroExecutionException
    {
        throw new MockMacroExecutionException("Macro execution error");
    }
}
