/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.xml.internal.parser;

import java.io.Reader;

import org.xwiki.rendering.block.XDOM;
import org.xwiki.rendering.internal.parser.XDOMGeneratorListener;
import org.xwiki.rendering.parser.ParseException;
import org.xwiki.rendering.parser.Parser;
import org.xwiki.rendering.parser.xml.ContentHandlerBlockParser;
import org.xwiki.rendering.parser.xml.ContentHandlerBlockParserFactory;

/**
 * Base class for all XML based parsers. This support both block based and streaming renderers interfaces.
 *
 * @version $Id: 1e0fc395fc8e4178938df8b1b26ec4a7525b07fc $
 * @since 5.2M1
 */
public abstract class AbstractParser extends AbstractStreamParser implements Parser, ContentHandlerBlockParserFactory
{
    @Override
    public XDOM parse(Reader source) throws ParseException
    {
        XDOMGeneratorListener listener = new XDOMGeneratorListener();

        parse(source, listener);

        return listener.getXDOM();
    }

    @Override
    public ContentHandlerBlockParser createBlockParser()
    {
        XDOMGeneratorListener listener = new XDOMGeneratorListener();

        return new ProxyContentHandlerBlockParser(createParser(listener), listener);
    }
}
